==> openwebmail-2.32.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/pl/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pkt)":  "1",
		"2 (10 pkt)": "2",
		"3 (12 pkt)": "3",
		"4 (14 pkt)": "4",
		"5 (18 pkt)": "5",
		"6 (24 pkt)": "6",
		"7 (36 pkt)": "7"
	},

	formatblock: {
		"Nagwek 1": "h1",
		"Nagwek 2": "h2",
		"Nagwek 3": "h3",
		"Nagwek 4": "h4",
		"Nagwek 5": "h5",
		"Nagwek 6": "h6",
		"Normalny": "p",
		"cze": "address",
		"Sformatowany": "pre"
	},

	tooltips: {
		bold:           "Pogrubienie",
		italic:         "Pochylenie",
		underline:      "Podkrelenie",
		strikethrough:  "Przekrelenie",
		subscript:      "Indeks dolny",
		superscript:    "Indeks grny",
		justifyleft:    "Wyrwnaj do lewej",
		justifycenter:  "Wyrodkuj",
		justifyright:   "Wyrwnaj do prawej",
		justifyfull:    "Wyjustuj",
		insertorderedlist:    "Lista numerowana",
		insertunorderedlist:  "Lista zwyczajna",
		outdent:        "Zmniejsz wcicie",
		indent:         "Zwiksz wcicie",
		forecolor:      "Kolor czcionki",
		hilitecolor:    "Kolor ta",
		horizontalrule: "Linia pozioma",
		createlink:     "Wstaw cze",
		insertimage:    "Wstaw obrazek",
		insertsound:    "Wstaw dwik",
		inserttable:    "Wstaw tabelk",
		htmlmode:       "Koloruj skadni HTML",
		popupeditor:    "Powiksz edytor",
		about:          "O edytorze",
		showhelp:       "Pomoc",
		textindicator:  "Aktualny styl",
		undo:           "Cofa Twoj ostatni akcj",
		redo:           "Powtarza Twoj ostatni akcj",
		cut:            "Wytnij zaznaczenie",
		copy:           "Kopiuj zaznaczenie",
		paste:          "Wklej ze schowka"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Anuluj"
	},

	msg: {
		"Path":         "cieka",
		"TEXT_MODE":    "Uywasz trybu TEKSTU.  Uyj przycisku [<>] aby powrci do trybu WYSIWIG."
	}
};

==> openwebmail-2.51p2.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/pl/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pkt)":  "1",
		"2 (10 pkt)": "2",
		"3 (12 pkt)": "3",
		"4 (14 pkt)": "4",
		"5 (18 pkt)": "5",
		"6 (24 pkt)": "6",
		"7 (36 pkt)": "7"
	},

	formatblock: {
		"Nagwek 1": "h1",
		"Nagwek 2": "h2",
		"Nagwek 3": "h3",
		"Nagwek 4": "h4",
		"Nagwek 5": "h5",
		"Nagwek 6": "h6",
		"Normalny": "p",
		"cze": "address",
		"Sformatowany": "pre"
	},

	tooltips: {
		bold:           "Pogrubienie",
		italic:         "Pochylenie",
		underline:      "Podkrelenie",
		strikethrough:  "Przekrelenie",
		subscript:      "Indeks dolny",
		superscript:    "Indeks grny",
		justifyleft:    "Wyrwnaj do lewej",
		justifycenter:  "Wyrodkuj",
		justifyright:   "Wyrwnaj do prawej",
		justifyfull:    "Wyjustuj",
		insertorderedlist:    "Lista numerowana",
		insertunorderedlist:  "Lista zwyczajna",
		outdent:        "Zmniejsz wcicie",
		indent:         "Zwiksz wcicie",
		forecolor:      "Kolor czcionki",
		hilitecolor:    "Kolor ta",
		inserthorizontalrule: "Linia pozioma",
		createlink:     "Wstaw cze",
		insertimage:    "Wstaw obrazek",
		insertsound:    "Wstaw dwik",
		inserttable:    "Wstaw tabelk",
		htmlmode:       "Koloruj skadni HTML",
		popupeditor:    "Powiksz edytor",
		about:          "O edytorze",
		showhelp:       "Pomoc",
		textindicator:  "Aktualny styl",
		undo:           "Cofa Twoj ostatni akcj",
		redo:           "Powtarza Twoj ostatni akcj",
		cut:            "Wytnij zaznaczenie",
		copy:           "Kopiuj zaznaczenie",
		paste:          "Wklej ze schowka"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Anuluj"
	},

	msg: {
		"Path":         "cieka",
		"TEXT_MODE":    "Uywasz trybu TEKSTU.  Uyj przycisku [<>] aby powrci do trybu WYSIWIG."
	}
};
